/*
 * packetmodeller/netdevice.h
 *
 * Copyright (C) 2008-2009 Reto Gantenbein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#ifndef __NETDEV_H
#define __NETDEV_H

#include <netinet/in.h>

/** Public Functions */

/**
 * Return the MAC address of the given interface
 * @param mac - 6 bytes char array to fill in mac address
 * @param dev_name - device of requested address
 */
int
get_mac_by_dev(unsigned char *mac, const ifname *dev_name);

/**
 * Return the IP address to a given interface
 * @param addr - struct to fill with ip address
 * @param dev_name - device of requested address
 */
int
get_ip_by_dev(struct in_addr *addr, const ifname *dev_name);

/**
 * Initialize address struct with data from given interface and port
 * @param addr - struct to fill
 * @param dev - device to retrieve information from
 * @param port - port to fill in addr (0 = random port)
 */
int
get_addr(struct sockaddr_in *addr, const ifname *dev, const uint16_t port);

/**
 * Create UDP socket and bind to given interface
 * @param dev - device name (e.g. eth0)
 * @param port - port to bind to
 * @return socket device file descriptor for network device
 */
int
alloc_net_socket(const ifname *dev, const uint16_t port);

/**
 * Return the character device file descriptor for the TAP device
 * @param dev - device name (e.g. v_ath0)
 */
int
alloc_tap_socket(const ifname *dev);

#endif
